@@ -17,6 +17,7 @@
 #ifndef KONQSIDEBARPART_H
 #define KONQSIDEBARPART_H
 
+#include <kparts_version.h>
 #include <kparts/part.h>
 #include <kparts/browserextension.h>
 #include <QPointer>
@@ -29,7 +30,7 @@ class KonqSidebarBrowserExtension : public KParts::BrowserExtension
     Q_OBJECT
 public:
     KonqSidebarBrowserExtension(KonqSidebarPart *part, Sidebar_Widget *widget);
-    ~KonqSidebarBrowserExtension() {}
+    ~KonqSidebarBrowserExtension() override {}
 
 protected:
     QPointer<Sidebar_Widget> widget;
@@ -78,23 +79,27 @@ public:
     /**
      * Default constructor
      */
+#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
+    KonqSidebarPart(QWidget *parentWidget, QObject *parent, const KPluginMetaData& metaData, const QVariantList &);
+#else
     KonqSidebarPart(QWidget *parentWidget, QObject *parent, const QVariantList &);
+#endif
 
     /**
      * Destructor
      */
-    virtual ~KonqSidebarPart();
+    ~KonqSidebarPart() override;
 
-    virtual bool openUrl(const QUrl &url) override;
+    bool openUrl(const QUrl &url) override;
 
 protected:
     /**
      * This must be implemented by each part
      */
     KonqSidebarBrowserExtension *m_extension;
-    virtual bool openFile() override;
+    bool openFile() override;
 
-    virtual void customEvent(QEvent *ev) override;
+    void customEvent(QEvent *ev) override;
 
 private:
     Sidebar_Widget *m_widget;
